@@ -11,6 +11,7 @@ INPUT_NIGHT_FOLDER_NAME_DATE_FORMAT = "%B %d, %Y"
 OUTPUT_NIGHT_FOLDER_NAME_DATE_FORMAT = "%B %d, %Y"
 LOG_FILE_COMBINED_FILENAME_DATE_FORMAT = "%m-%d-%y"
 FLUX_LOG_COMBINED_FILENAME_DATE_FORMAT = "%m-%d-%y"
+COLOR_NORMALIZED_FILENAME_DATE_FORMAT = "%m-%d-%y"
 
 # Output folder/file name conventions
 CONFIG_FILE_NAME = "config.toml"
@@ -18,6 +19,8 @@ OUTPUT_CALIBRATION_FOLDER_NAME = "Calibration Frames"
 ALIGNED_COMBINED_FOLDER_NAME = "Aligned Combined"
 LOG_FILES_COMBINED_FOLDER_NAME = "Log Files Combined"
 FLUX_LOGS_COMBINED_FOLDER_NAME = "Flux Logs Combined"
+COLOR_NORMALIZED_FOLDER_NAME = "Color Normalized"
+CHARTS_FOLDER_NAME = "Charts"
 MASTER_DARK_NAME = "masterdark.fit"
 MASTER_FLAT_NAME = "masterflat.fit"
 
