@@ -1,5 +1,6 @@
 from .generate_masterflat import generate_masterflat
 from .process_nights import start_data_processing
 from .renormalize import renormalize
+from .nights_csv import create_nights_csv
 
-__all__ = ["start_data_processing", "renormalize", "generate_masterflat"]
+__all__ = ["start_data_processing", "renormalize", "generate_masterflat", "create_nights_csv"]
